@@ -4,6 +4,19 @@ knitr::opts_chunk$set(
   comment = "#>"
 )
 
+chk_online <- FALSE
+
+library(pingr)
+
+# helper function to check if a sub-domain is online
+online <- function(h_url){
+  !is.na(pingr::ping(h_url, count = 1))
+}
+
+# check if sub-domains are online
+chk_online   <- online("kyy.hydroscope.gr")
+
+
 ## ----load_libraries-----------------------------------------------------------
 library(hydroscoper)
 library(ggplot2)
@@ -32,19 +45,19 @@ ggplot() +
   coord_fixed(ratio=1) +
   theme_bw()
 
-## ----subset_timeseries--------------------------------------------------------
-station_ts <- subset(timeseries, station_id == 200200)
-station_ts
+## ----subset_timeseries, eval = chk_online-------------------------------------
+#  station_ts <- subset(timeseries, station_id == 200200)
+#  station_ts
 
-## ----get_timeseries-----------------------------------------------------------
-ts_raw <- get_data(subdomain = "kyy", time_id = 56)
-ts_raw
+## ----get_timeseries, eval = chk_online----------------------------------------
+#  ts_raw <- get_data(subdomain = "kyy", time_id = 56)
+#  ts_raw
 
-## ----plot_time_series---------------------------------------------------------
-ggplot(data = ts_raw, aes(x = date, y = value))+
-  geom_line()+
-  labs(title= "30 min precipitation", 
-       subtitle = "station 200200",
-       x="Date", y = "Rain height (mm)")+
-  theme_classic()
+## ----plot_time_series, eval = chk_online--------------------------------------
+#  ggplot(data = ts_raw, aes(x = date, y = value))+
+#    geom_line()+
+#    labs(title= "30 min precipitation",
+#         subtitle = "station 200200",
+#         x="Date", y = "Rain height (mm)")+
+#    theme_classic()
 
